@@ -7,7 +7,7 @@ use Mojo::Util qw( camelize );
 #------------------------------------------------------------------------------
 #   Crud 版本信息
 #------------------------------------------------------------------------------
-our $VERSION = '0.0.7';
+our $VERSION = '0.0.8';
 
 #------------------------------------------------------------------------------
 #   Crud 插件注册方法
@@ -55,13 +55,13 @@ sub register {
       # 处理 "/$name/:id" 样式路由，GET DELETE PUT
       $resource = $r->under(
         "/$route_part/:id" => sub {
-          my $c      = shift;
-          my %params = $c->req->params->to_hash();
-          $c->app->log->debug( sprintf( "Storable: \$c->stash('form_id')->{'%s'} = %s", $name, $params{"id"} ) );
+          my $c  = shift;
+          my $id = $c->req->query_params->param('id');
+          $c->app->log->debug( sprintf( "Storable: \$c->stash('form_id')->{'%s'} = %s", $name, $id ) );
 
           # 检查是否存在$c->stash('fm.ids')，并写入 URI 表单ID
           $c->stash( 'form_id' => {} ) unless $c->stash('form_id');
-          $c->stash('form_id')->{$name} = $params{"id"};
+          $c->stash('form_id')->{$name} = $id;
           return 1;
         }
       )->to( controller => $controller, idname => "id" );
